@@ -23,11 +23,12 @@ CONSUMER_SECRET = os.getenv('TWITTER_CONSUMER_SECRET')
 ACCESS_TOKEN_KEY = os.getenv('TWITTER_ACCESS_TOKEN_KEY')
 ACCESS_TOKEN_SECRET = os.getenv('TWITTER_ACCESS_TOKEN_SECRET')
 SPACE_REGEX = re.compile(r"[ \n]{2,}")
-ES_ENABLED = os.environ.get('ES_ENABLED', 'False') == 'True' 
+ES_ENABLED = os.environ.get('ES_ENABLED', 'False') == 'True'
 TWITTER_ENABLED = os.getenv('TWITTER_ENABLED', 'False') == 'True'
 
+
 class SantaMonicaScraper(EngageScraper):
-    def __init__(self, tz_string="America/Los_Angeles", years=["2019"], committee="Santa Monica City Council"):
+    def __init__(self, tz_string="America/Los_Angeles", years=["2019"]):
         super().__init__(tz_string)
 
         # Requests/HTML session
@@ -40,22 +41,16 @@ class SantaMonicaScraper(EngageScraper):
         # For tweeting
         if TWITTER_ENABLED:
             self._twitter_util = TwitterUtil(CONSUMER_KEY,
-                                            CONSUMER_SECRET,
-                                            ACCESS_TOKEN_KEY,
-                                            ACCESS_TOKEN_SECRET)
+                                             CONSUMER_SECRET,
+                                             ACCESS_TOKEN_KEY,
+                                             ACCESS_TOKEN_SECRET)
 
         # Create tables
         create_postgres_tables(Base, self._engine)
         seed_tables(self._DBsession)
 
-        # Retrieve committee
-        self._Committee = self._DBsession().query(Committee).filter(
-            Committee.name == committee).first()
-
         # Extra SM specific parameters
         self._years = years
-        self._agendas_table_location = self._Committee.agendas_table_location
-        self.base_agenda_location = self._Committee.base_agenda_location
 
         # Instantiate elasticsearch utility object
         if ES_ENABLED:
@@ -77,7 +72,17 @@ class SantaMonicaScraper(EngageScraper):
     def base_agenda_location(self, base_location):
         self._base_agenda_location = base_location
 
+    def set_committee(self, commmittee):
+        committee = self._DBsession().query(Committee).filter(
+            Committee.name == committee).first()
+        if committee is not None:
+            self._Committee = committee
+            self._agendas_table_location = self._Committee.agendas_table_location
+            self.base_agenda_location = self._Committee.base_agenda_location
+
     def get_available_agendas(self):
+        if self._Committee is None:
+            return
         """
         First gets the agenda main page to retrieve updated ASPX embeded content
         """
@@ -117,6 +122,8 @@ class SantaMonicaScraper(EngageScraper):
         """
         scrape only unprocessed agendas
         """
+        if self._Committee is None:
+            return
         session = self._DBsession()
         committeeid = self._Committee.id
         committees_meetings = session.query(Agenda).filter(
@@ -161,13 +168,15 @@ class SantaMonicaScraper(EngageScraper):
                         stored_agenda = self._store_agenda(agenda)
                         # now store items
                         self._store_agenda_items(agenda, stored_agenda)
-                        newdate= timestamp_to_month_date(meeting_time, self._tz)
+                        newdate = timestamp_to_month_date(
+                            meeting_time, self._tz)
                         if (newdate[0]):
                             if SCRAPER_DEBUG:
                                 log.error("Sending tweet for {} meeting {} at {}".format(
                                     self._Committee.name, agenda["meeting_id"], meeting_time))
                             if TWITTER_ENABLED:
-                                self._twitter_util.tweet("Agenda Items for the next @santamonicacity City Council meeting is open for public feedback until 11:59:59AM {}. Head to http://sm.engage.town now to voice your opinion!".format(newdate[1]))
+                                self._twitter_util.tweet(
+                                    "Agenda Items for the next @santamonicacity City Council meeting is open for public feedback until 11:59:59AM {}. Head to http://sm.engage.town now to voice your opinion!".format(newdate[1]))
 
     def _process_agenda(self, agenda_data, meeting_id):
         date_time_string = agenda_data.find(
@@ -453,7 +462,7 @@ class SantaMonicaScraper(EngageScraper):
                     es_load = self._elasticsearch_utility.postItems(es_item)
                     if SCRAPER_DEBUG:
                         log.info(es_load)
-                
+
         except Exception as exc:
             log.error(
                 "Something happened when adding agenda items from agenda {}: {}".format(agenda_saved.id, str(exc)))
